@@ -1,4 +1,4 @@
-use std::fmt::{Debug, Display};
+use std::fmt::{Debug, Display, Formatter};
 
 use serde_json::Value;
 
@@ -9,14 +9,11 @@ use crate::crud::{CRUDTable, Skip};
 use std::ops::{Deref, DerefMut};
 use std::collections::HashMap;
 use serde::{Serialize, Deserialize, Serializer, Deserializer};
+use serde::de::DeserializeOwned;
+use std::marker::PhantomData;
 
 /// Logic Delete Plugin trait
 pub trait LogicDelete: Send + Sync + Debug {
-    ///the name
-    fn name(&self) -> &str {
-        std::any::type_name::<Self>()
-    }
-
     /// database column
     fn column(&self) -> &str;
     /// deleted data,must be i32
@@ -33,9 +30,7 @@ pub trait LogicDelete: Send + Sync + Debug {
     ) -> Result<String, crate::core::Error>;
 }
 
-#[derive(Debug)]
 pub struct RbatisLogicDeletePlugin {
-    pub excludes: Vec<String>,
     pub column: String,
     pub deleted: i32,
     pub un_deleted: i32,
@@ -44,18 +39,17 @@ pub struct RbatisLogicDeletePlugin {
 impl RbatisLogicDeletePlugin {
     pub fn new(column: &str) -> Self {
         Self {
-            excludes: vec![],
             column: column.to_string(),
             deleted: 1,
             un_deleted: 0,
         }
     }
+
     pub fn new_opt(column: &str, deleted: i32, un_deleted: i32) -> Self {
         if deleted == un_deleted {
             panic!("[rbaits] deleted can not equal to un_deleted on RbatisLogicDeletePlugin::new_opt(column: &str, deleted: i32, un_deleted: i32)")
         }
         Self {
-            excludes: vec![],
             column: column.to_string(),
             deleted,
             un_deleted,
@@ -63,6 +57,13 @@ impl RbatisLogicDeletePlugin {
     }
 }
 
+impl Debug for RbatisLogicDeletePlugin {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("RbatisLogicDeletePlugin")
+            .finish()
+    }
+}
+
 impl LogicDelete for RbatisLogicDeletePlugin {
     fn column(&self) -> &str {
         self.column.as_str()
@@ -83,7 +84,8 @@ impl LogicDelete for RbatisLogicDeletePlugin {
         table_fields: &str,
         sql_where: &str,
     ) -> Result<String, Error> {
-        return if table_fields.contains(self.column()) {
+        let fields: Vec<&str> = table_fields.split(",").collect();
+        return if fields.contains(&self.column()) {
             //fields have column
             if sql_where.is_empty() {
                 let new_sql = format!(
@@ -119,80 +121,4 @@ impl LogicDelete for RbatisLogicDeletePlugin {
             Err(Error::from("[rbatis] del data must have where sql!"))
         };
     }
-}
-
-
-/// use this context will not use logic del
-pub struct TableNoLogic<T> where T: CRUDTable {
-    pub table: T,
-}
-
-impl<T> Serialize for TableNoLogic<T> where T: CRUDTable {
-    fn serialize<S>(&self, serializer: S) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error> where
-        S: Serializer {
-        T::serialize(&self.table, serializer)
-    }
-}
-
-impl<'de, T> Deserialize<'de> for TableNoLogic<T> where T: CRUDTable {
-    fn deserialize<D>(deserializer: D) -> Result<Self, <D as Deserializer<'de>>::Error> where
-        D: Deserializer<'de> {
-        let result = T::deserialize(deserializer)?;
-        return Ok(TableNoLogic {
-            table: result,
-        });
-    }
-}
-
-
-impl<T> CRUDTable for TableNoLogic<T> where T: CRUDTable {
-    fn is_use_plugin(plugin_name: &str) -> bool {
-        if plugin_name.eq(std::any::type_name::<RbatisLogicDeletePlugin>()) {
-            return false;
-        }
-        return true;
-    }
-
-    fn table_name() -> String {
-        T::table_name()
-    }
-
-    fn table_columns() -> String {
-        T::table_columns()
-    }
-
-    fn formats(driver_type: &DriverType) -> HashMap<String, fn(arg: &str) -> String> {
-        T::formats(driver_type)
-    }
-
-    fn make_value_sql_arg(
-        &self,
-        db_type: &DriverType,
-        index: &mut usize,
-        skips: &[Skip]
-    ) -> crate::Result<(String, String, Vec<serde_json::Value>)> {
-        T::make_value_sql_arg(&self.table, db_type, index,skips)
-    }
-}
-
-impl<T> Deref for TableNoLogic<T> where T: CRUDTable {
-    type Target = T;
-
-    fn deref(&self) -> &Self::Target {
-        &self.table
-    }
-}
-
-impl<T> DerefMut for TableNoLogic<T> where T: CRUDTable {
-    fn deref_mut(&mut self) -> &mut Self::Target {
-        &mut self.table
-    }
-}
-
-impl<T> From<T> for TableNoLogic<T> where T: CRUDTable {
-    fn from(arg: T) -> Self {
-        TableNoLogic {
-            table: arg
-        }
-    }
-}
+}
\ No newline at end of file
