@@ -18,7 +18,6 @@ use crate::plugin::intercept::SqlIntercept;
 use crate::plugin::log::{LogPlugin, RbatisLogPlugin};
 use crate::plugin::logic_delete::{LogicDelete, RbatisLogicDeletePlugin};
 use crate::plugin::page::{IPage, IPageRequest, Page, PagePlugin, RbatisPagePlugin};
-use crate::plugin::version_lock::{RbatisVersionLockPlugin, VersionLockPlugin};
 use crate::sql::PageLimit;
 use crate::utils::error_util::ToResult;
 use crate::utils::string_util;
@@ -34,12 +33,10 @@ pub struct Rbatis {
     pub page_plugin: Box<dyn PagePlugin>,
     // sql intercept vec chain
     pub sql_intercepts: Vec<Box<dyn SqlIntercept>>,
-    // logic delete plugin
-    pub logic_plugin: Option<Box<dyn LogicDelete>>,
     // log plugin
     pub log_plugin: Arc<Box<dyn LogPlugin>>,
-    // version lock plugin
-    pub version_lock_plugin: Option<Box<dyn VersionLockPlugin>>,
+    // logic delete plugin
+    pub logic_plugin: Option<Box<dyn LogicDelete>>,
     // sql param binder
     pub encoder: fn(q: &mut DBQuery, arg: &serde_json::Value) -> crate::Result<()>,
 }
@@ -51,7 +48,6 @@ impl Debug for Rbatis {
             .field("page_plugin",&self.page_plugin)
             .field("sql_intercepts",&self.sql_intercepts)
             .field("logic_plugin",&self.logic_plugin)
-            .field("version_lock_plugin",&self.version_lock_plugin)
             .finish()
     }
 }
@@ -70,12 +66,10 @@ pub struct RbatisOption {
     pub page_plugin: Box<dyn PagePlugin>,
     /// sql intercept vec chain
     pub sql_intercepts: Vec<Box<dyn SqlIntercept>>,
-    /// logic delete plugin
-    pub logic_plugin: Option<Box<dyn LogicDelete>>,
     /// log plugin
     pub log_plugin: Arc<Box<dyn LogPlugin>>,
-    ///version lock plugin
-    pub version_lock_plugin: Option<Box<dyn VersionLockPlugin>>,
+    /// logic delete plugin
+    pub logic_plugin: Option<Box<dyn LogicDelete>>,
 }
 
 impl Default for RbatisOption {
@@ -85,7 +79,6 @@ impl Default for RbatisOption {
             sql_intercepts: vec![],
             logic_plugin: None,
             log_plugin: Arc::new(Box::new(RbatisLogPlugin::default()) as Box<dyn LogPlugin>),
-            version_lock_plugin: None,
         }
     }
 }
@@ -104,7 +97,6 @@ impl Rbatis {
             sql_intercepts: option.sql_intercepts,
             logic_plugin: option.logic_plugin,
             log_plugin: option.log_plugin,
-            version_lock_plugin: None,
             encoder: |q,arg|{
                 q.bind_value(arg)?;
                 Ok(())
@@ -175,15 +167,8 @@ impl Rbatis {
         self.log_plugin = Arc::new(Box::new(arg));
     }
 
-    pub fn set_logic_plugin(&mut self, arg: Option<impl LogicDelete + 'static>) {
-        match arg {
-            Some(v) => {
-                self.logic_plugin = Some(Box::new(v));
-            }
-            None => {
-                self.logic_plugin = None;
-            }
-        }
+    pub fn set_logic_plugin(&mut self, arg: impl LogicDelete + 'static) {
+        self.logic_plugin = Some(Box::new(arg));
     }
 
     pub fn set_page_plugin(&mut self, arg: impl PagePlugin + 'static) {
